#define SELECT_H

/****************************************************************

    Copyright (c) 1996-1997 Fred Pesch

    This program is free software; you can redistribute it 
    and/or modify it under the terms of the GNU General 
    Public License as published by the Free Software 
    Foundation (version 2 of the License).

    This program is distributed in the hope that it will 
    be useful, but WITHOUT ANY WARRANTY; without even the 
    implied warranty of MERCHANTABILITY or FITNESS FOR A 
    PARTICULAR PURPOSE.  See the GNU General Public License 
    for more details.

    For a copy of the GNU General Public License, write to the 
    Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
    MA 02139, USA.

****************************************************************/

#include <Xm/Xm.h>
#include <Xm/XmAll.h>
#include <glob.h>
#include <errno.h>
#include <unistd.h>

#include "fileview.h"
#include "interface.h"
#include "dirtree.h"
#include "error_handler.h"

extern void SelectionCB(Widget w_notebook, XtPointer app_data, XtPointer widget_data);

void SelectAllCommand(void)
{
  TViewNode *actual;
  WidgetList selection;
  int nbselection;
  XmContainerSelectCallbackStruct * infos;

  nbselection=0;
  actual=ActualFileViewList;
  while(actual!=NULL) {
    if(strcmp(actual->filenode->file.name,"..")!=0) nbselection++;
    actual=actual->next;
  }

  if(nbselection==0) return;

  selection = (WidgetList) XtMalloc(sizeof(Widget)*nbselection);
  
  nbselection=0;
  actual=ActualFileViewList;
  while(actual!=NULL) {
    if(strcmp(actual->filenode->file.name,"..")!=0) {
      selection[nbselection]=FileIconList.w_icon[actual->icon_index];
      nbselection++;
    }
    actual=actual->next;
  }

  XtVaSetValues(W_ListFile, XmNselectedObjectCount, nbselection, XmNselectedObjects, selection, NULL);

  infos = (XmContainerSelectCallbackStruct *) XtMalloc(sizeof(XmContainerSelectCallbackStruct));
  infos->selected_item_count = nbselection;
  infos->selected_items = selection;

  SelectionCB(NULL, NULL, infos);

  XtFree((char*) selection);
  XtFree((char*) infos);
}

void UnSelectAllCommand(void)
{
  WidgetList selection;
  int nbselection;
  XmContainerSelectCallbackStruct * infos;

  nbselection=0;
  selection = NULL;
  
  XtVaSetValues(W_ListFile, XmNselectedObjectCount, nbselection, XmNselectedObjects, selection, NULL);

  infos = (XmContainerSelectCallbackStruct *) XtMalloc(sizeof(XmContainerSelectCallbackStruct));
  infos->selected_item_count = nbselection;
  infos->selected_items = selection;

  SelectionCB(NULL, NULL, infos);

  XtFree((char*) infos);
}

void SelectFilterCommandRoutine(char *pattern)
{
  glob_t globbuf;
  int result;
  TViewNode *actual;
  int i,found;
  int nbselection;
  XmContainerSelectCallbackStruct * infos;
  WidgetList selection;

  globbuf.gl_offs=0;
  result = glob(pattern, GLOB_ERR, NULL, &globbuf);
  if(result==0 && globbuf.gl_pathc==1) {
    if(strcmp(globbuf.gl_pathv[0],".")==0 || strcmp(globbuf.gl_pathv[0],"..")==0 ) 
      result=1;
    else {
      result = access(globbuf.gl_pathv[0], R_OK);
      if(result==-1 && errno==ENOENT) result=1;
    }
  } 
  if(result!=0) {
    MessageDialog("Filter Select", "no found matches");
    return;
  }

  selection=(WidgetList) XtMalloc(sizeof(Widget)*globbuf.gl_pathc);

  nbselection=0;
  actual=ActualFileViewList;
  while(actual!=NULL) {
    i=0;
    found=0;
    while(!found && i<globbuf.gl_pathc) {
      if(strcmp(actual->filenode->file.name,"..")!=0 && strcmp(actual->filenode->file.name,".")!=0 && strcmp(actual->filenode->file.name,globbuf.gl_pathv[i])==0)
	 found = 1;
      else i++;
    }
    if(found) {
      selection[nbselection]=FileIconList.w_icon[actual->icon_index];
      nbselection++;
    }
    actual=actual->next;
  }

  XtVaSetValues(W_ListFile, XmNselectedObjectCount, nbselection, XmNselectedObjects, selection, NULL);

  infos = (XmContainerSelectCallbackStruct *) XtMalloc(sizeof(XmContainerSelectCallbackStruct));
  infos->selected_item_count = nbselection;
  infos->selected_items = selection;

  SelectionCB(NULL, NULL, infos);

  XmScrollVisible(W_ScrollList, FileIconList.w_icon[SelectFileViewList->icon_index], 10, 10);

  globfree(&globbuf);
  XtFree((char*) selection);
  XtFree((char*) infos);
}
	 

     
	
  


